Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BlockDevice ¶
type BlockDevice struct {
ID bson.ObjectId `bson:"_id,omitempty"`
VolID bson.ObjectId `bson:"volID"` //can be empty
Path string `bson:"path,omitempty"`
UUID string `bson:"uuid,omitempty"`
Type string `bson:"type,omitempty"`
}
BlockDevice represents a block device retrieved by blkid probe
type BtrfsVolume ¶
type BtrfsVolume struct {
ID bson.ObjectId `bson:"_id,omitempty"`
ServID bson.ObjectId `bson:"servID"` // can be empty
Label string `bson:"label"`
}
BtrfsVolume represents a filesystem volume which can potentially span over multiple devices
type StorageServer ¶
StorageServer represents a Network Attached Storage device
type User ¶
type User struct {
ID bson.ObjectId `bson:"_id,omitempty"`
Username string `bson:"username,omitempty"`
HashedPassword string `bson:"hashedPassword,omitempty"`
FirstName string `bson:"firstName"`
LastName string `bson:"lastName"`
RegistrationDate time.Time `bson:"registrationDate"`
}
User model
Click to show internal directories.
Click to hide internal directories.